@@ -16,8 +16,7 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-"""This module contains the class Updater, which tries to make creating
-Telegram bots intuitive."""
+"""This module contains the class Updater, which tries to make creating Telegram bots intuitive."""
 
 import logging
 import os
@@ -70,14 +69,17 @@ class Updater(object):
         user_sig_handler (:obj:`function`, optional): Takes ``signum, frame`` as positional
             arguments. This will be called when a signal is received, defaults are (SIGINT,
             SIGTERM, SIGABRT) setable with :attr:`idle`.
-        request_kwargs (:obj:`dict`, optional): Keyword args to control the creation of a request
-            object (ignored if `bot` argument is used).
+        request_kwargs (:obj:`dict`, optional): Keyword args to control the creation of a
+            `telegram.utils.request.Request` object (ignored if `bot` argument is used). The
+            request_kwargs are very useful for the advanced users who would like to control the
+            default timeouts and/or control the proxy used for http communication.
 
     Note:
         You must supply either a :attr:`bot` or a :attr:`token` argument.
 
     Raises:
         ValueError: If both :attr:`token` and :attr:`bot` are passed or none of them.
+
     """
 
     _request = None
@@ -95,8 +97,16 @@ class Updater(object):
         if (token is not None) and (bot is not None):
             raise ValueError('`token` and `bot` are mutually exclusive')
 
+        self.logger = logging.getLogger(__name__)
+
+        con_pool_size = workers + 4
+
         if bot is not None:
             self.bot = bot
+            if bot.request.con_pool_size < con_pool_size:
+                self.logger.warning(
+                    'Connection pool of Request object is smaller than optimal value (%s)',
+                    con_pool_size)
         else:
             # we need a connection pool the size of:
             # * for each of the workers
@@ -107,7 +117,7 @@ class Updater(object):
             if request_kwargs is None:
                 request_kwargs = {}
             if 'con_pool_size' not in request_kwargs:
-                request_kwargs['con_pool_size'] = workers + 4
+                request_kwargs['con_pool_size'] = con_pool_size
             self._request = Request(**request_kwargs)
             self.bot = Bot(token, base_url, request=self._request)
         self.user_sig_handler = user_sig_handler
@@ -121,7 +131,6 @@ class Updater(object):
             workers=workers,
             exception_event=self.__exception_event)
         self.last_update_id = 0
-        self.logger = logging.getLogger(__name__)
         self.running = False
         self.is_idle = False
         self.httpd = None
@@ -152,8 +161,7 @@ class Updater(object):
                       bootstrap_retries=0,
                       read_latency=2.,
                       allowed_updates=None):
-        """
-        Starts polling updates from Telegram.
+        """Starts polling updates from Telegram.
 
         Args:
             poll_interval (:obj:`float`, optional): Time to wait between polling updates from
@@ -178,6 +186,7 @@ class Updater(object):
 
         Returns:
             :obj:`Queue`: The update queue that can be filled from the main thread.
+
         """
 
         if network_delay is not None:
@@ -222,8 +231,8 @@ class Updater(object):
             key (:obj:`str`, optional): Path to the SSL key file.
             clean (:obj:`bool`, optional): Whether to clean any pending updates on Telegram servers
                 before actually starting the webhook. Default is ``False``.
-            bootstrap_retries (Optional[int[): Whether the bootstrapping phase of the `Updater`
-                will retry on failures on the Telegram server.
+            bootstrap_retries (:obj:`int`, optional): Whether the bootstrapping phase of the
+                `Updater` will retry on failures on the Telegram server.
 
                 * < 0 - retry indefinitely
                 *   0 - no retries (default)
@@ -236,6 +245,7 @@ class Updater(object):
 
         Returns:
             :obj:`Queue`: The update queue that can be filled from the main thread.
+
         """
 
         with self.__lock:
@@ -252,7 +262,7 @@ class Updater(object):
                 return self.update_queue
 
     def _start_polling(self, poll_interval, timeout, read_latency, bootstrap_retries, clean,
-                       allowed_updates):
+                       allowed_updates):  # pragma: no cover
         # """
         # Thread target of thread 'updater'. Runs in background, pulls
         # updates from Telegram and inserts them in the update queue of the
@@ -397,9 +407,7 @@ class Updater(object):
             updates = self.bot.get_updates(updates[-1].update_id + 1)
 
     def stop(self):
-        """
-        Stops the polling/webhook thread, the dispatcher and the job queue.
-        """
+        """Stops the polling/webhook thread, the dispatcher and the job queue."""
 
         self.job_queue.stop()
         with self.__lock:
@@ -447,15 +455,14 @@ class Updater(object):
             os._exit(1)
 
     def idle(self, stop_signals=(SIGINT, SIGTERM, SIGABRT)):
-        """
-        Blocks until one of the signals are received and stops the updater.
+        """Blocks until one of the signals are received and stops the updater.
 
         Args:
             stop_signals (:obj:`iterable`): Iterable containing signals from the signal module that
                 should be subscribed to. Updater.stop() will be called on receiving one of those
                 signals. Defaults to (``SIGINT``, ``SIGTERM``, ``SIGABRT``).
-        """
 
+        """
         for sig in stop_signals:
             signal(sig, self.signal_handler)
 
