@@ -16,10 +16,9 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-"""This module contains the classes that represent Telegram
-InlineQueryResultGif"""
+"""This module contains the classes that represent Telegram InlineQueryResultGif."""
 
-from telegram import InlineQueryResult, InlineKeyboardMarkup, InputMessageContent
+from telegram import InlineQueryResult
 
 
 class InlineQueryResultGif(InlineQueryResult):
@@ -57,6 +56,7 @@ class InlineQueryResultGif(InlineQueryResult):
         input_message_content (:class:`telegram.InputMessageContent`, optional): Content of the
             message to be sent instead of the gif.
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
+
     """
 
     def __init__(self,
@@ -92,16 +92,3 @@ class InlineQueryResultGif(InlineQueryResult):
             self.reply_markup = reply_markup
         if input_message_content:
             self.input_message_content = input_message_content
-
-    @classmethod
-    def de_json(cls, data, bot):
-        data = super(InlineQueryResultGif, cls).de_json(data, bot)
-
-        if not data:
-            return None
-
-        data['reply_markup'] = InlineKeyboardMarkup.de_json(data.get('reply_markup'), bot)
-        data['input_message_content'] = InputMessageContent.de_json(
-            data.get('input_message_content'), bot)
-
-        return cls(**data)
